﻿using System.IO;
using System.Linq;
using System.Windows;
using Infragistics.Controls.Grids;
using Infragistics.Documents.Excel;

namespace SpreadsheetMinimalPrototype
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		public MainWindow()
		{
			InitializeComponent();

			using (var fs = File.OpenRead("../../../Test.xlsx"))
			{
				// Load Worksheet
				var workbook = Workbook.Load(fs);

				// Protect Worksheet
				workbook.Worksheets.First().Protect(allowDeletingColumns: false, allowInsertingColumns: false, allowEditObjects: true,
					allowDeletingRows: true, allowEditScenarios: true, allowFiltering: true, allowFormattingCells: true,
					allowFormattingColumns: true, allowFormattingRows: true, allowInsertingHyperlinks: true,
					allowInsertingRows: true, allowSorting: true, allowUsingPivotTables: false);

				// Unprotect cells in the second row (first data row)
				workbook.Worksheets.First().Rows[1].Cells[2].CellFormat.Locked = ExcelDefaultableBoolean.False;
				workbook.Worksheets.First().Rows[1].Cells[0].CellFormat.Locked = ExcelDefaultableBoolean.False;
				workbook.Worksheets.First().Rows[1].Cells[1].CellFormat.Locked = ExcelDefaultableBoolean.False;

				spreadSheet.Workbook = workbook;
			}
		}

		private void spreadSheet_CommandExecuting(object sender, SpreadsheetCommandExecutingEventArgs e)
		{
			if (e.Command == SpreadsheetCommandType.DeleteRows)
			{
				int startRow = 0;
				int endRow = 0;

				//hardocded used columns indexes
				int startColumn = 0;
				int endColumn = 2;
				XamSpreadsheet spreadsheet = sender as XamSpreadsheet;

				int cellRangesCount = spreadsheet.ActiveSelection.CellRanges.Count;
				startRow = spreadsheet.ActiveSelection.CellRanges[0].FirstRow;
				endRow = spreadsheet.ActiveSelection.CellRanges[cellRangesCount - 1].LastRow;

				System.Console.WriteLine("Before modifying default ActiveSelection cell range: ");
				foreach (SpreadsheetCellRange scr in spreadsheet.ActiveSelection.CellRanges)
				{
					System.Console.WriteLine(scr);
				}

				spreadsheet.ActiveSelection.ClearCellRanges();
				spreadsheet.ActiveSelection.ReplaceActiveCellRange(
					new SpreadsheetCellRange(startRow, startColumn, endRow, endColumn),
					spreadsheet.ActiveCell
				);

				System.Console.WriteLine("Set selected rows: First " + (startRow + 1).ToString() + ", Last: " +
					(endRow + 1).ToString());

				System.Console.WriteLine("After modifying default ActiveSelection cell range: ");
				foreach (SpreadsheetCellRange scr in spreadsheet.ActiveSelection.CellRanges)
				{
					System.Console.WriteLine(scr);
				}

				System.Console.WriteLine("Row deleted!");
			}

			if (e.Command == SpreadsheetCommandType.Paste)
			{
				int startRow = 0;
				int endRow = 0;

				//hardocded used columns indexes
				int startColumn = 0;
				int endColumn = 2;
				XamSpreadsheet spreadsheet = sender as XamSpreadsheet;

				int cellRangesCount = spreadsheet.ActiveSelection.CellRanges.Count;
				startRow = spreadsheet.ActiveSelection.CellRanges[0].FirstRow;
				endRow = spreadsheet.ActiveSelection.CellRanges[cellRangesCount - 1].LastRow;

				System.Console.WriteLine("Before modifying default ActiveSelection cell range: ");
				foreach (SpreadsheetCellRange scr in spreadsheet.ActiveSelection.CellRanges)
				{
					System.Console.WriteLine(scr);
				}

				spreadsheet.ActiveSelection.ClearCellRanges();
				spreadsheet.ActiveSelection.ReplaceActiveCellRange(
					new SpreadsheetCellRange(startRow, startColumn, endRow, endColumn),
					spreadsheet.ActiveCell
				);

				System.Console.WriteLine("Set selected rows: First " + (startRow + 1).ToString() + ", Last: " +
					(endRow + 1).ToString());

				System.Console.WriteLine("After modifying default ActiveSelection cell range: ");
				foreach (SpreadsheetCellRange scr in spreadsheet.ActiveSelection.CellRanges)
				{
					System.Console.WriteLine(scr);
				}

				System.Console.WriteLine("Row pasted!");
			}
		}

	}
}
